Stan Math Library: stan/math/prim/mat/meta/is_vector.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
is_vector.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/meta/is_vector.hpp>`

Go to the source code of this file.

## Classes
struct | stan::is_vector< Eigen::Matrix< T, Eigen::Dynamic, 1 > >
struct | stan::is_vector< Eigen::Matrix< T, 1, Eigen::Dynamic > >
struct | stan::is_vector< Eigen::Block< T > >

## Namespaces
| stan

[ Stan Home Page ] © 2011–2016, Stan Development Team.